@@ -5,10 +5,12 @@ import re
 import sys
 
 from collections import defaultdict
+from itertools import ifilter, imap
 
 import smokesignal
 
 from helga import log, settings
+from helga.util.encodings import to_unicode
 
 
 logger = log.getLogger(__name__)
@@ -70,12 +72,10 @@ class Registry(object):
             self.plugins = {}
 
         if not hasattr(self, 'enabled_plugins'):
+            # Enabled plugins is a dict: channel -> set()
             self.enabled_plugins = defaultdict(lambda: set(getattr(settings, 'ENABLED_PLUGINS', [])))
 
-        @smokesignal.on('started')
-        def load_plugins():
-            self.load()
-            smokesignal.emit('plugins_loaded')
+        smokesignal.on('started', self.load)
 
     def register(self, name, fn_or_cls):
         # Make sure we're working with an instance
@@ -86,9 +86,9 @@ class Registry(object):
             pass
 
         if not (isinstance(fn_or_cls, Plugin) or hasattr(fn_or_cls, '_plugins')):
-            raise TypeError("Plugin {0} must be a subclass of Plugin, or a decorated function".format(name))
+            raise TypeError(u"Plugin {0} must be a subclass of Plugin, or a decorated function".format(name))
 
-        logger.info('Registered plugin {0}'.format(name))
+        logger.info('Registered plugin %s', name)
         self.plugins[name] = fn_or_cls
 
     @property
@@ -96,7 +96,7 @@ class Registry(object):
         return set(self.plugins.keys())
 
     def get_plugin(self, name):
-        return self.plugins[name]
+        return self.plugins.get(name, None)
 
     def disable(self, channel, *plugins):
         self.enabled_plugins[channel] = self.enabled_plugins[channel].difference(set(plugins))
@@ -119,14 +119,15 @@ class Registry(object):
         """
         for entry_point in pkg_resources.iter_entry_points(group='helga_plugins'):
             try:
-                logger.debug('Loading entry_point {0}'.format(entry_point.name))
+                logger.debug('Loading entry_point %s', entry_point.name)
                 self.register(entry_point.name, entry_point.load())
             except:
-                logger.exception("Error initializing plugin {0}".format(entry_point))
+                logger.exception('Error initializing plugin %s', entry_point)
+        smokesignal.emit('plugins_loaded')
 
     def reload(self, name):
         if name not in self.plugins:
-            return "Unknown plugin '{0}'. Is it installed?".format(name)
+            return u"Unknown plugin '{0}'. Is it installed?".format(name)
 
         for entry_point in pkg_resources.iter_entry_points(group='helga_plugins'):
             if entry_point.name != name:
@@ -137,7 +138,7 @@ class Registry(object):
                 self.register(entry_point.name, entry_point.load())
                 return True
             except:
-                logger.exception('Failed to reload plugin {0}'.format(entry_point))
+                logger.exception('Failed to reload plugin %s', entry_point)
                 return False
 
     def prioritized(self, channel, high_to_low=True):
@@ -147,9 +148,7 @@ class Registry(object):
         plugins = []
         for name in self.enabled_plugins[channel]:
             if name not in self.plugins:
-                logger.debug(
-                    'Plugin {0} may not be installed or have incorrect entry_point information'.format(name)
-                )
+                logger.debug('Plugin %s may not be installed or have incorrect entry_point information', name)
                 continue
 
             # Decorated functions will have this
@@ -165,7 +164,7 @@ class Registry(object):
             try:
                 channel, nick, message = plugin.preprocess(client, channel, nick, message)
             except:
-                logger.exception("Calling preprocess on plugin {0} failed".format(plugin))
+                logger.exception('Calling preprocess on plugin %s failed', plugin)
                 continue
 
         return channel, nick, message
@@ -178,11 +177,10 @@ class Registry(object):
             try:
                 resp = plugin.process(client, channel, nick, message)
             except ResponseNotReady:
-                if first_responder:
-                    return filter(bool, responses)
+                break
             except:
-                logger.exception("Calling process on plugin {0} failed".format(plugin))
-                resp = None
+                logger.exception('Calling process on plugin %s failed', plugin)
+                continue
 
             if not resp:
                 continue
@@ -190,14 +188,16 @@ class Registry(object):
             # Chained decorator style plugins return a list of strings
             if isinstance(resp, (tuple, list)):
                 # Be sure to filter Nones, then strip
-                responses.extend(map(lambda s: s.strip(), filter(bool, resp)))
+                responses.extend(imap(lambda s: (s or '').strip(), resp))
             else:
                 responses.append(resp.strip())
 
             if responses and first_responder:
-                return filter(bool, responses)
+                break
 
-        return filter(bool, responses)
+        # FIXME: Explicit conversion to unicode might not make sense. Perpahs
+        # a warning should be sent to the user? Or do we even care?
+        return map(to_unicode, ifilter(bool, responses))
 
 
 registry = Registry()
@@ -244,7 +244,7 @@ class Plugin(object):
         :param nick: the current nick of the message sender
         :param message: the message string itself
         """
-        return None
+        return None  # pragma: no cover
 
     def preprocess(self, client, channel, nick, message):
         """
@@ -261,7 +261,7 @@ class Plugin(object):
         :param nick: the current nick of the message sender
         :param message: the message string itself
         """
-        return channel, nick, message
+        return channel, nick, message  # pragma: no cover
 
     def process(self, client, channel, nick, message):
         """
@@ -375,16 +375,16 @@ class Command(Plugin):
         # short alias versions will trump the more verbose ones
         choices = sorted(choices, key=len, reverse=True)
 
+        nick_prefix = ''
+
         # Handle multiple ways to parse this command
         if getattr(settings, 'COMMAND_PREFIX_BOTNICK', True):
             nick_prefix = '{0}\W*\s'.format(botnick)
-        else:
-            nick_prefix = ''
 
         prefixes = filter(bool, [nick_prefix, getattr(settings, 'COMMAND_PREFIX_CHAR', '!')])
         prefix = '({0})'.format('|'.join(prefixes))
 
-        pat = r'^{0}({1})($|\s(.*)$)'.format(prefix, '|'.join(choices))
+        pat = ur'^{0}({1})($|\s(.*)$)'.format(prefix, '|'.join(choices))
 
         try:
             _, cmd, _, argstr = re.findall(pat, message, re.IGNORECASE)[0]
@@ -407,7 +407,7 @@ class Command(Plugin):
         :param command: the parsed command, which is either the preferred command or a command alias
         :param args: a list of strings, space delimited, that follow the command
         """
-        return None
+        return None  # pragma: no cover
 
     def process(self, client, channel, nick, message):
         """
@@ -489,7 +489,7 @@ class Match(Plugin):
         :param matches: if the ``pattern`` attribute of this class is a callable, this will be its
                         return value, otherwise it will be the return value of ``re.findall``
         """
-        return None
+        return None  # pragma: no cover
 
     def match(self, message):
         """
